@@ -30,7 +30,7 @@ def send_plain_email(to, from_, subject, txt, server=('localhost', 25)):
 
 # define test fixture here again in order to run tests without having to
 # install the plugin anew every single time
-smtpsserver = plugin.smtpserver
+smtpserver = plugin.smtpserver
 
 
 def test_smtpserver_funcarg(smtpserver):
